@@ -176,9 +176,9 @@ class unit_conversion():
             pts = self.__ppm2pts(val)
         elif units == "HZ":
             pts = self.__hz2pts(val)
-        elif units == "%" or units == "PERCENT":
+        elif units in ("%", "PERCENT"):
             pts = self.__percent2pts(val)
-        elif units == "SEC" or units == "SECOND" or units == "S":
+        elif units in ("SEC", "SECOND", "S"):
             pts = self.__sec2pts(val)
         elif units == "MS":
             pts = self.__ms2pts(val)
@@ -202,9 +202,9 @@ class unit_conversion():
             k = self.__pts2ppm(val)
         elif units == "HZ":
             k = self.__pts2hz(val)
-        elif units == "%" or units == "PERCENT":
+        elif units in ("%", "PERCENT"):
             k = self.__pts2percent(val)
-        elif units == "SEC" or units == "SECOND" or units == "S":
+        elif units in ("SEC", "SECOND", "S"):
             k = self.__pts2sec(val)
         elif units == "MS":
             k = self.__pts2ms(val)
@@ -655,7 +655,7 @@ class data_nd:
         """ Set the ndim and shape attributes from fshape """
         # set ndim and shape
         self.ndim = len(self.fshape)
-        self.shape = tuple([self.fshape[i] for i in self.order])
+        self.shape = tuple(self.fshape[i] for i in self.order)
 
     def __copy__(self):
         """
@@ -797,4 +797,4 @@ class data_nd:
             raise ValueError("repeated axis in tranpose")
 
         # create a new data_nd object with transposed order
-        return self.__fcopy__(order=tuple([self.order[i] for i in axes]))
+        return self.__fcopy__(order=tuple(self.order[i] for i in axes))
